@@ -19,12 +19,18 @@ function deactivate_mdraid {
 
 function activate_mdraid {
     declare kiwi_RaidDev=${kiwi_RaidDev}
-    set_device_lock "${kiwi_RaidDev}" \
-        mdadm --assemble --scan "${kiwi_RaidDev}"
+    mdadm --assemble --scan "${kiwi_RaidDev}"
     wait_for_storage_device "${kiwi_RaidDev}"
     set_root_map "${kiwi_RaidDev}"
 }
 
+function update_devicesize_mdraid {
+    declare kiwi_RaidDev=${kiwi_RaidDev}
+    mdadm --assemble --scan "${kiwi_RaidDev}" --update=devicesize
+    wait_for_storage_device "${kiwi_RaidDev}"
+    deactivate_mdraid
+}
+
 function resize_mdraid {
     declare kiwi_RaidDev=${kiwi_RaidDev}
     set_device_lock "${kiwi_RaidDev}" \
