@@ -166,6 +166,7 @@ class DiskBuilder:
         self.luks = xml_state.get_luks_credentials()
         self.use_disk_password = \
             xml_state.get_build_type_bootloader_use_disk_password()
+        self.host_key_certificates = xml_state.get_host_key_certificates()
         self.integrity = xml_state.build_type.get_standalone_integrity()
         self.integrity_legacy_hmac = \
             xml_state.build_type.get_integrity_legacy_hmac()
@@ -419,7 +420,64 @@ class DiskBuilder:
             compress=compression,
             shasum=True
         )
-
+        if self.host_key_certificates and 's390' in self.arch:
+            self.result.add(
+                key='secure_execution_header',
+                filename=os.path.normpath(
+                    os.sep.join(
+                        [
+                            self.target_dir,
+                            '{0}.{1}-{2}.{3}'.format(
+                                self.xml_state.xml_data.get_name(),
+                                self.arch,
+                                self.xml_state.get_image_version(),
+                                'secure_execution_header.bin'
+                            )
+                        ]
+                    )
+                ),
+                use_for_bundle=True,
+                compress=False,
+                shasum=False
+            )
+            self.result.add(
+                key='attestation_response_key',
+                filename=os.path.normpath(
+                    os.sep.join(
+                        [
+                            self.target_dir,
+                            '{0}.{1}-{2}.{3}'.format(
+                                self.xml_state.xml_data.get_name(),
+                                self.arch,
+                                self.xml_state.get_image_version(),
+                                'attestation_response.key'
+                            )
+                        ]
+                    )
+                ),
+                use_for_bundle=True,
+                compress=False,
+                shasum=False
+            )
+            self.result.add(
+                key='attestation_request',
+                filename=os.path.normpath(
+                    os.sep.join(
+                        [
+                            self.target_dir,
+                            '{0}.{1}-{2}.{3}'.format(
+                                self.xml_state.xml_data.get_name(),
+                                self.arch,
+                                self.xml_state.get_image_version(),
+                                'attestation_request.bin'
+                            )
+                        ]
+                    )
+                ),
+                use_for_bundle=True,
+                compress=False,
+                shasum=False
+            )
         # create image root metadata
         self.result.add(
             key='image_packages',
@@ -557,7 +615,9 @@ class DiskBuilder:
             'boot_is_crypto':
                 self.boot_is_crypto,
             'config_options':
-                self.xml_state.get_bootloader_config_options()
+                self.xml_state.get_bootloader_config_options(),
+            'target_dir':
+                self.target_dir
         }
         if self.bootloader.startswith('grub'):
             custom_args.update(
@@ -1112,7 +1172,8 @@ class DiskBuilder:
             log.info('--> creating EFI CSM(legacy bios) partition')
             partition_mbsize = self.firmware.get_legacy_bios_partition_size()
             disk.create_efi_csm_partition(
-                partition_mbsize
+                partition_mbsize,
+                self.xml_state.build_type.get_eficsmpart_id()
             )
             disksize_used_mbytes += partition_mbsize
 
@@ -1120,7 +1181,8 @@ class DiskBuilder:
             log.info('--> creating EFI partition')
             partition_mbsize = self.firmware.get_efi_partition_size()
             disk.create_efi_partition(
-                partition_mbsize
+                partition_mbsize,
+                self.xml_state.build_type.get_efipart_id()
             )
             disksize_used_mbytes += partition_mbsize
 
@@ -1140,7 +1202,8 @@ class DiskBuilder:
             )
             partition_mbsize = self.disk_setup.boot_partition_size()
             disk.create_boot_partition(
-                format(partition_mbsize), self.boot_clone_count
+                format(partition_mbsize), self.boot_clone_count,
+                self.xml_state.build_type.get_bootpart_id()
             )
             disksize_used_mbytes += \
                 (self.boot_clone_count + 1) * partition_mbsize if \
@@ -1210,7 +1273,14 @@ class DiskBuilder:
             if root_clone_count:
                 rootfs_mbsize = int(rootfs_mbsize / (root_clone_count + 1))
         else:
-            if self.oem_systemsize and not self.oem_resize:
+            if self.oem_systemsize and (
+                not self.oem_resize or self.spare_part_is_last
+            ):
+                # if resize on boot is switched off, we have to take
+                # the given size into account at build time.
+                # if resize is active but the rootfs is not the last
+                # partition we also have to take the given size into
+                # account, because only the last can resize
                 rootfs_mbsize = self.oem_systemsize
             else:
                 rootfs_mbsize = 'all_free'
@@ -1257,7 +1327,10 @@ class DiskBuilder:
                         root_clone_count
                     )
                 )
-                disk.create_root_partition(rootfs_mbsize, root_clone_count)
+                disk.create_root_partition(
+                    rootfs_mbsize, root_clone_count,
+                    self.xml_state.build_type.get_rootpart_id()
+                )
 
         if self.spare_part_is_last:
             log.info('--> creating spare partition')
