@@ -5,8 +5,6 @@ from unittest.mock import (
 from pytest import (
     raises, fixture
 )
-from lxml import etree
-from xml.dom import minidom
 
 import pytest
 
@@ -111,9 +109,10 @@ class TestVolumeManagerBtrfs:
 
         self.volume_manager.setup()
 
-        mock_mount.assert_called_once_with(
-            device='/dev/storage', mountpoint='tmpdir'
-        )
+        assert mock_mount.call_args_list == [
+            call(device='/dev/storage', mountpoint='tmpdir'),
+            call(device='tmpdir/@', mountpoint='tmpdir/@')
+        ]
         toplevel_mount.mount.assert_called_once_with([])
         assert mock_command.call_args_list == [
             call(['btrfs', 'subvolume', 'create', 'tmpdir/@']),
@@ -121,26 +120,27 @@ class TestVolumeManagerBtrfs:
             call(['btrfs', 'subvolume', 'set-default', '256', 'tmpdir'])
         ]
 
-    @patch('os.chmod')
     @patch('os.path.exists')
     @patch('kiwi.volume_manager.btrfs.Command.run')
+    @patch('kiwi.volume_manager.btrfs.SnapshotManager.new')
     @patch('kiwi.volume_manager.btrfs.FileSystem.new')
     @patch('kiwi.volume_manager.btrfs.MappedDevice')
     @patch('kiwi.volume_manager.btrfs.MountManager')
     @patch('kiwi.volume_manager.base.Temporary')
     def test_setup_with_snapshot(
         self, mock_Temporary, mock_mount, mock_mapped_device, mock_fs,
-        mock_command, mock_os_exists, mock_os_chmod
+        mock_snapshot_mngr, mock_command, mock_os_exists
     ):
+        snapper = Mock()
+        snapper.create_first_snapshot = Mock(return_value=[mock_mount])
+        snapper.get_default_snapshot_name = Mock()
+        mock_snapshot_mngr.return_value = snapper
+
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
         toplevel_mount = Mock()
         mock_mount.return_value = toplevel_mount
-        command_call = Mock()
-        command_call.output = \
-            'ID 258 gen 26 top level 257 path @/.snapshots/1/snapshot'
         mock_mapped_device.return_value = 'mapped_device'
         mock_os_exists.return_value = False
-        mock_command.return_value = command_call
         self.volume_manager.custom_args['root_is_snapper_snapshot'] = True
         self.volume_manager.custom_args['quota_groups'] = True
 
@@ -148,29 +148,18 @@ class TestVolumeManagerBtrfs:
 
         assert mock_mount.call_args_list == [
             call(device='/dev/storage', mountpoint='tmpdir'),
-            call(
-                device='/dev/storage',
-                attributes={
-                    'subvol_path': '@/.snapshots',
-                    'subvol_name': '@/.snapshots'
-                },
-                mountpoint='tmpdir/@/.snapshots/1/snapshot/.snapshots'
-            ),
             call(
                 device='tmpdir/@/.snapshots/1/snapshot',
                 mountpoint='tmpdir/@/.snapshots/1/snapshot'
             )
         ]
         toplevel_mount.mount.assert_called_once_with([])
+        snapper.create_first_snapshot.assert_called_once_with()
+        snapper.get_default_snapshot_name.assert_called_once_with()
         assert mock_command.call_args_list == [
             call(['btrfs', 'quota', 'enable', 'tmpdir']),
-            call(['btrfs', 'subvolume', 'create', 'tmpdir/@']),
-            call(['btrfs', 'subvolume', 'create', 'tmpdir/@/.snapshots']),
-            call(['btrfs', 'subvolume', 'create', 'tmpdir/@/.snapshots/1/snapshot']),
-            call(['btrfs', 'subvolume', 'list', 'tmpdir']),
-            call(['btrfs', 'subvolume', 'set-default', '258', 'tmpdir'])
+            call(['btrfs', 'subvolume', 'create', 'tmpdir/@'])
         ]
-        mock_os_chmod.assert_called_once_with('tmpdir/@/.snapshots', 0o700)
 
     @patch('os.path.exists')
     @patch('kiwi.volume_manager.btrfs.Command.run')
@@ -402,6 +391,7 @@ class TestVolumeManagerBtrfs:
 
     def test_umount_volumes(self):
         self.volume_manager.toplevel_mount = Mock()
+        self.volume_manager.root_volume_mount = Mock()
         volume_mount = Mock()
         volume_mount.is_mounted = Mock(
             return_value=True
@@ -422,63 +412,27 @@ class TestVolumeManagerBtrfs:
         self.volume_manager.snapshots_root_mount.is_mounted.assert_called_once_with()
         self.volume_manager.snapshots_root_mount.umount.assert_called_once_with()
         self.volume_manager.toplevel_mount.is_mounted.assert_called_once_with()
+        self.volume_manager.root_volume_mount.umount.assert_called_once_with()
         self.volume_manager.toplevel_mount.umount.assert_called_once_with()
 
-    @patch('kiwi.volume_manager.btrfs.SysConfig')
     @patch('kiwi.volume_manager.btrfs.DataSync')
-    @patch('kiwi.volume_manager.btrfs.Command.run')
-    @patch('os.path.exists')
-    @patch('shutil.copyfile')
-    @patch.object(datetime, 'datetime', Mock(wraps=datetime.datetime))
-    def test_sync_data(
-        self, mock_copy, mock_exists, mock_command,
-        mock_sync, mock_sysconf
-    ):
-        item = {'SNAPPER_CONFIGS': '""'}
-
-        def getitem(key):
-            return item[key]
-
-        def setitem(key, value):
-            item[key] = value
-
-        def contains(key):
-            return key in item
-
-        def exists(name):
-            if 'snapper/configs/root' in name:
-                return False
-            return True
-
+    def test_sync_data(self, mock_sync):
         self.volume_manager.custom_args['quota_groups'] = True
-        mock_exists.side_effect = exists
 
-        sysconf = Mock()
-        sysconf.__contains__ = Mock(side_effect=contains)
-        sysconf.__getitem__ = Mock(side_effect=getitem)
-        sysconf.__setitem__ = Mock(side_effect=setitem)
-        mock_sysconf.return_value = sysconf
+        snapper = Mock()
+        snapper.setup_first_snapshot = Mock()
 
-        xml_info = etree.tostring(etree.parse(
-            '../data/info.xml', etree.XMLParser(remove_blank_text=True)
-        ))
-        datetime.datetime.now.return_value = datetime.datetime(2016, 1, 1)
+        self.volume_manager.snapper = snapper
         self.volume_manager.toplevel_mount = Mock()
         self.volume_manager.mountpoint = 'tmpdir'
         self.volume_manager.custom_args['root_is_snapper_snapshot'] = True
         sync = Mock()
         mock_sync.return_value = sync
 
-        m_open = mock_open()
-        with patch('builtins.open', m_open, create=True):
-            self.volume_manager.sync_data(['exclude_me'])
+        self.volume_manager.sync_data(['exclude_me'])
 
         root_path = 'tmpdir/@/.snapshots/1/snapshot'
         mock_sync.assert_called_once_with('root_dir', root_path)
-        mock_copy.assert_called_once_with(
-            root_path + '/etc/snapper/config-templates/default',
-            root_path + '/etc/snapper/configs/root'
-        )
         sync.sync_data.assert_called_once_with(
             exclude=['exclude_me'],
             options=[
@@ -486,74 +440,6 @@ class TestVolumeManagerBtrfs:
                 '--acls', '--one-file-system', '--inplace'
             ]
         )
-        assert m_open.call_args_list == [
-            call('tmpdir/@/.snapshots/1/info.xml', 'w'),
-        ]
-        assert m_open.return_value.write.call_args_list == [
-            call(minidom.parseString(xml_info).toprettyxml(indent="    "))
-        ]
-        assert mock_command.call_args_list == [
-            call(['btrfs', 'qgroup', 'create', '1/0', 'tmpdir']),
-            call([
-                'chroot', 'tmpdir/@/.snapshots/1/snapshot',
-                'snapper', '--no-dbus', 'set-config', 'QGROUP=1/0'
-            ])
-        ]
-
-    @patch('kiwi.volume_manager.btrfs.SysConfig')
-    @patch('kiwi.volume_manager.btrfs.DataSync')
-    @patch('kiwi.volume_manager.btrfs.Command.run')
-    @patch('os.path.exists')
-    @patch.object(datetime, 'datetime', Mock(wraps=datetime.datetime))
-    def test_sync_data_existing_bad_snapper_config(
-        self, mock_exists, mock_command, mock_sync, mock_sysconf
-    ):
-        item = {'SNAPPER_CONFIGS': '"root foo"'}
-
-        def getitem(key):
-            return item[key]
-
-        def contains(key):
-            return key in item
-
-        sysconf = Mock()
-        sysconf.__contains__ = Mock(side_effect=contains)
-        sysconf.__getitem__ = Mock(side_effect=getitem)
-        mock_sysconf.return_value = sysconf
-
-        self.volume_manager.custom_args['quota_groups'] = True
-        mock_exists.return_value = True
-        xml_info = etree.tostring(etree.parse(
-            '../data/info.xml', etree.XMLParser(remove_blank_text=True)
-        ))
-        datetime.datetime.now.return_value = datetime.datetime(2016, 1, 1)
-        self.volume_manager.toplevel_mount = Mock()
-        self.volume_manager.mountpoint = 'tmpdir'
-        self.volume_manager.custom_args['root_is_snapper_snapshot'] = True
-        sync = Mock()
-        mock_sync.return_value = sync
-
-        m_open = mock_open()
-        with patch('builtins.open', m_open, create=True):
-            with raises(KiwiVolumeManagerSetupError):
-                self.volume_manager.sync_data(['exclude_me'])
-
-        mock_sync.assert_called_once_with(
-            'root_dir', 'tmpdir/@/.snapshots/1/snapshot'
-        )
-        sync.sync_data.assert_called_once_with(
-            exclude=['exclude_me'],
-            options=[
-                '--archive', '--hard-links', '--xattrs', '--acls',
-                '--one-file-system', '--inplace'
-            ]
-        )
-        assert m_open.call_args_list == [
-            call('tmpdir/@/.snapshots/1/info.xml', 'w'),
-        ]
-        assert m_open.return_value.write.call_args_list == [
-            call(minidom.parseString(xml_info).toprettyxml(indent="    "))
-        ]
 
     @patch('kiwi.volume_manager.btrfs.DataSync')
     @patch('kiwi.volume_manager.btrfs.Command.run')
@@ -609,5 +495,6 @@ class TestVolumeManagerBtrfs:
             self.device_map, 'root_dir', self.volumes
         ) as volume_manager:
             volume_manager.toplevel_mount = Mock()
+            volume_manager.root_volume_mount = Mock()
 
         mock_VolumeManagerBtrfs_umount_volumes.assert_called_once_with()
